@@ -922,6 +922,8 @@ char *prog;
 	case ANYOF:
 	    if (strchr(OPERAND(scan), *reginput) == NULL)
 		return(0);
+	    if (*reginput == '\0')
+	    	return(0);
 	    reginput++;
 	    break;
 	case ANYBUT:
@@ -1188,7 +1190,7 @@ int max;
 	    (void) strncpy(dst, prog->startp[no], len);
 	    adjustcase(dst, len, chgcase);
 	    dst += len;
-	    if (*(dst-1) == '\0') {     /* strncpy hit NUL. */
+	    if (len != 0 && *(dst-1) == '\0') {     /* strncpy hit NUL. */
 		regerror("damaged match string");
 		return;
 	    }
