@@ -320,6 +320,8 @@ void TextDRedisplayRange(textDisp *textD, int start, int end)
        
     /* Clean up the starting and ending values */
     if (start < 0) start = 0;
+    if (start > textD->buffer->length) start = textD->buffer->length;
+    if (end < 0) end = 0;
     if (end > textD->buffer->length) end = textD->buffer->length;
     
     /* Get the starting and ending lines */
@@ -408,8 +410,11 @@ void TextDGetScroll(textDisp *textD, int *topLineNum, int *horizOffset)
 */
 void TextDSetInsertPosition(textDisp *textD, int newPos)
 {
+    /* make sure new position is ok, do nothing if it hasn't changed */
     if (newPos == textD->cursorPos)
     	return;
+    if (newPos < 0) newPos = 0;
+    if (newPos > textD->buffer->length) newPos = textD->buffer->length;
  
     /* cursor movement cancels vertical cursor motion column */
     textD->cursorPreferredCol = -1;
@@ -1245,10 +1250,10 @@ static void offsetLineStarts(textDisp *textD, int newTopLineNum)
     	/* printf("counting forward %d lines from start of last line\n",
     		newTopLineNum - lastLineNum); */
     } else {
-    	textD->firstChar = BufCountBackwardNLines(buf, buf->length-1,
-		textD->nBufferLines - newTopLineNum);
+    	textD->firstChar = BufCountBackwardNLines(buf, buf->length,
+		textD->nBufferLines - newTopLineNum + 1);
 	/* printf("counting backward %d lines from end\n",
-    		textD->nBufferLines - newTopLineNum); */
+    		textD->nBufferLines - newTopLineNum + 1); */
     }
     
     /* Fill in the line starts array */
