@@ -893,7 +893,7 @@ static Widget createTextArea(Widget parent, WindowInfo *window, int rows,
     Pixel troughColor;
     XFontStruct *fs;
     int marginHeight;
-    Dimension hsbHeight;
+    Dimension hsbHeight, swMarginHeight;
         
     /* Create a text widget inside of a scrolled window widget */
     sw = XtVaCreateManagedWidget("scrolledW", xmScrolledWindowWidgetClass,
@@ -936,9 +936,11 @@ static Widget createTextArea(Widget parent, WindowInfo *window, int rows,
     XtVaSetValues(sw, XmNbackground, troughColor, 0);
 
     /* set the minimum size of a pane */
+    XtVaGetValues(sw, XmNscrolledWindowMarginHeight, &swMarginHeight, 0);
     XtVaGetValues(text, textNmarginHeight, &marginHeight, textNfont, &fs, 0);
     XtVaGetValues(hScrollBar, XmNheight, &hsbHeight, 0);
-    setPaneMinHeight(sw, fs->ascent + fs->descent + marginHeight*2 + hsbHeight);
+    setPaneMinHeight(sw, fs->ascent + fs->descent + marginHeight*2 +
+    	    swMarginHeight*2 + hsbHeight);
     
     /* compensate for Motif delete/backspace problem */
     RemapDeleteKey(text);
